# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.self_service.account.v0 import managing_account_service_pb2 as qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2


class ManagingAccountServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateAccountCreationRequest = channel.unary_unary(
                '/qwak.self_service.account.v0.ManagingAccountService/CreateAccountCreationRequest',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.CreateAccountCreationRequestRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.CreateAccountCreationRequestResponse.FromString,
                )
        self.ValidateAccountCreationRequest = channel.unary_unary(
                '/qwak.self_service.account.v0.ManagingAccountService/ValidateAccountCreationRequest',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.ValidateAccountCreationRequestRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.ValidateAccountCreationRequestResponse.FromString,
                )
        self.GetAccountStatus = channel.unary_unary(
                '/qwak.self_service.account.v0.ManagingAccountService/GetAccountStatus',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetAccountStatusRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetAccountStatusResponse.FromString,
                )
        self.GetCloudProviderSupportedRegions = channel.unary_unary(
                '/qwak.self_service.account.v0.ManagingAccountService/GetCloudProviderSupportedRegions',
                request_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetCloudProviderSupportedRegionsRequest.SerializeToString,
                response_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetCloudProviderSupportedRegionsResponse.FromString,
                )


class ManagingAccountServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateAccountCreationRequest(self, request, context):
        """Create account creation request
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateAccountCreationRequest(self, request, context):
        """Validate account creation request
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountStatus(self, request, context):
        """Get account status
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCloudProviderSupportedRegions(self, request, context):
        """List all supported regions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ManagingAccountServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateAccountCreationRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccountCreationRequest,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.CreateAccountCreationRequestRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.CreateAccountCreationRequestResponse.SerializeToString,
            ),
            'ValidateAccountCreationRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateAccountCreationRequest,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.ValidateAccountCreationRequestRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.ValidateAccountCreationRequestResponse.SerializeToString,
            ),
            'GetAccountStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountStatus,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetAccountStatusRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetAccountStatusResponse.SerializeToString,
            ),
            'GetCloudProviderSupportedRegions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCloudProviderSupportedRegions,
                    request_deserializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetCloudProviderSupportedRegionsRequest.FromString,
                    response_serializer=qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetCloudProviderSupportedRegionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.self_service.account.v0.ManagingAccountService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ManagingAccountService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateAccountCreationRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.ManagingAccountService/CreateAccountCreationRequest',
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.CreateAccountCreationRequestRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.CreateAccountCreationRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateAccountCreationRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.ManagingAccountService/ValidateAccountCreationRequest',
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.ValidateAccountCreationRequestRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.ValidateAccountCreationRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccountStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.ManagingAccountService/GetAccountStatus',
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetAccountStatusRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetAccountStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCloudProviderSupportedRegions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.self_service.account.v0.ManagingAccountService/GetCloudProviderSupportedRegions',
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetCloudProviderSupportedRegionsRequest.SerializeToString,
            qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__service__pb2.GetCloudProviderSupportedRegionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import Any


class BaseOutputAdapter:
    @property
    def config(self):
        return dict()

    def pack_user_func_return_value(
        self,
        return_result: Any,
    ) -> Any:
        """
        Pack the return value of user defined API function into InferenceResults
        """
        raise NotImplementedError()



from .authenticated_user.client import AuthenticatedUserClient
from .authentication.client import AuthenticationClient
from .environment.client import EnvironmentClient
from .self_service.client import SelfServiceUserClient



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _KubeAlertType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _KubeAlertTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_KubeAlertType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ALERT_TYPE_NOT_VALID: _KubeAlertType.ValueType  # 0
    ERROR_RATE: _KubeAlertType.ValueType  # 1
    THROUGHPUT: _KubeAlertType.ValueType  # 2
    LATENCY: _KubeAlertType.ValueType  # 3
    LATENCY_90: _KubeAlertType.ValueType  # 4
    LATENCY_95: _KubeAlertType.ValueType  # 5

class KubeAlertType(_KubeAlertType, metaclass=_KubeAlertTypeEnumTypeWrapper): ...

ALERT_TYPE_NOT_VALID: KubeAlertType.ValueType  # 0
ERROR_RATE: KubeAlertType.ValueType  # 1
THROUGHPUT: KubeAlertType.ValueType  # 2
LATENCY: KubeAlertType.ValueType  # 3
LATENCY_90: KubeAlertType.ValueType  # 4
LATENCY_95: KubeAlertType.ValueType  # 5
global___KubeAlertType = KubeAlertType

class _KubeReducerFunction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _KubeReducerFunctionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_KubeReducerFunction.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    REDUCER_FUNCTION_NOT_VALID: _KubeReducerFunction.ValueType  # 0
    MIN: _KubeReducerFunction.ValueType  # 1
    MAX: _KubeReducerFunction.ValueType  # 2
    SUM: _KubeReducerFunction.ValueType  # 3
    COUNT: _KubeReducerFunction.ValueType  # 4
    LAST: _KubeReducerFunction.ValueType  # 5
    MEDIAN: _KubeReducerFunction.ValueType  # 6
    DIFF: _KubeReducerFunction.ValueType  # 7
    DIFF_ABS: _KubeReducerFunction.ValueType  # 8
    PERCENT_DIFF: _KubeReducerFunction.ValueType  # 9
    PERCENT_DIFF_ABS: _KubeReducerFunction.ValueType  # 10

class KubeReducerFunction(_KubeReducerFunction, metaclass=_KubeReducerFunctionEnumTypeWrapper): ...

REDUCER_FUNCTION_NOT_VALID: KubeReducerFunction.ValueType  # 0
MIN: KubeReducerFunction.ValueType  # 1
MAX: KubeReducerFunction.ValueType  # 2
SUM: KubeReducerFunction.ValueType  # 3
COUNT: KubeReducerFunction.ValueType  # 4
LAST: KubeReducerFunction.ValueType  # 5
MEDIAN: KubeReducerFunction.ValueType  # 6
DIFF: KubeReducerFunction.ValueType  # 7
DIFF_ABS: KubeReducerFunction.ValueType  # 8
PERCENT_DIFF: KubeReducerFunction.ValueType  # 9
PERCENT_DIFF_ABS: KubeReducerFunction.ValueType  # 10
global___KubeReducerFunction = KubeReducerFunction

class _KubeEvaluatorType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _KubeEvaluatorTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_KubeEvaluatorType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EVALUATOR_TYPE_NOT_VALID: _KubeEvaluatorType.ValueType  # 0
    IS_ABOVE: _KubeEvaluatorType.ValueType  # 1
    IS_BELOW: _KubeEvaluatorType.ValueType  # 2

class KubeEvaluatorType(_KubeEvaluatorType, metaclass=_KubeEvaluatorTypeEnumTypeWrapper): ...

EVALUATOR_TYPE_NOT_VALID: KubeEvaluatorType.ValueType  # 0
IS_ABOVE: KubeEvaluatorType.ValueType  # 1
IS_BELOW: KubeEvaluatorType.ValueType  # 2
global___KubeEvaluatorType = KubeEvaluatorType

class KubeAlertRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNELS_FIELD_NUMBER: builtins.int
    ALERT_SPEC_FIELD_NUMBER: builtins.int
    VARIATION_NAME_FIELD_NUMBER: builtins.int
    @property
    def notification_channels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The channels to notify to"""
    @property
    def alert_spec(self) -> global___KubeAlertSpec:
        """The details of the alert"""
    variation_name: builtins.str
    """The variation name - if empty - general for the model."""
    def __init__(
        self,
        *,
        notification_channels: collections.abc.Iterable[builtins.str] | None = ...,
        alert_spec: global___KubeAlertSpec | None = ...,
        variation_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alert_spec", b"alert_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alert_spec", b"alert_spec", "notification_channels", b"notification_channels", "variation_name", b"variation_name"]) -> None: ...

global___KubeAlertRule = KubeAlertRule

class KubeAlertSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REDUCER_FUNCTION_FIELD_NUMBER: builtins.int
    EVALUATOR_TYPE_FIELD_NUMBER: builtins.int
    EVALUATOR_THRESHOLD_FIELD_NUMBER: builtins.int
    EVALUATION_PERIOD_FIELD_NUMBER: builtins.int
    ALERT_TYPE_FIELD_NUMBER: builtins.int
    EVALUATION_THRESHOLD_FIELD_NUMBER: builtins.int
    reducer_function: global___KubeReducerFunction.ValueType
    """Reducer Function e.g. min, max"""
    evaluator_type: global___KubeEvaluatorType.ValueType
    """Evaluator function type e.g. greeter then, lower then"""
    evaluator_threshold: builtins.int
    """Evaluator threshold to alert for"""
    evaluation_period: builtins.int
    """Evaluation period"""
    alert_type: global___KubeAlertType.ValueType
    """The type of alert"""
    evaluation_threshold: builtins.float
    """Evaluation threshold"""
    def __init__(
        self,
        *,
        reducer_function: global___KubeReducerFunction.ValueType = ...,
        evaluator_type: global___KubeEvaluatorType.ValueType = ...,
        evaluator_threshold: builtins.int = ...,
        evaluation_period: builtins.int = ...,
        alert_type: global___KubeAlertType.ValueType = ...,
        evaluation_threshold: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alert_type", b"alert_type", "evaluation_period", b"evaluation_period", "evaluation_threshold", b"evaluation_threshold", "evaluator_threshold", b"evaluator_threshold", "evaluator_type", b"evaluator_type", "reducer_function", b"reducer_function"]) -> None: ...

global___KubeAlertSpec = KubeAlertSpec

class KubeNotificationChannel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNEL_ID_FIELD_NUMBER: builtins.int
    NOTIFICATION_CHANNEL_NAME_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    notification_channel_id: builtins.str
    """Notification Channel id"""
    notification_channel_name: builtins.str
    """Notification Channel name"""
    @property
    def settings(self) -> global___KubeNotificationChannelSettings:
        """Specific settings"""
    def __init__(
        self,
        *,
        notification_channel_id: builtins.str = ...,
        notification_channel_name: builtins.str = ...,
        settings: global___KubeNotificationChannelSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification_channel_id", b"notification_channel_id", "notification_channel_name", b"notification_channel_name", "settings", b"settings"]) -> None: ...

global___KubeNotificationChannel = KubeNotificationChannel

class KubeNotificationChannelSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SLACK_SETTINGS_FIELD_NUMBER: builtins.int
    OPSGENIE_SETTINGS_FIELD_NUMBER: builtins.int
    @property
    def slack_settings(self) -> global___KubeSlackNotificationChannelSettings: ...
    @property
    def opsgenie_settings(self) -> global___KubeOpsgenieNotificationChannelSettings: ...
    def __init__(
        self,
        *,
        slack_settings: global___KubeSlackNotificationChannelSettings | None = ...,
        opsgenie_settings: global___KubeOpsgenieNotificationChannelSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["opsgenie_settings", b"opsgenie_settings", "settings", b"settings", "slack_settings", b"slack_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["opsgenie_settings", b"opsgenie_settings", "settings", b"settings", "slack_settings", b"slack_settings"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["settings", b"settings"]) -> typing_extensions.Literal["slack_settings", "opsgenie_settings"] | None: ...

global___KubeNotificationChannelSettings = KubeNotificationChannelSettings

class KubeSlackNotificationChannelSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNEL_URL_FIELD_NUMBER: builtins.int
    notification_channel_url: builtins.str
    def __init__(
        self,
        *,
        notification_channel_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification_channel_url", b"notification_channel_url"]) -> None: ...

global___KubeSlackNotificationChannelSettings = KubeSlackNotificationChannelSettings

class KubeOpsgenieNotificationChannelSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_URL_FIELD_NUMBER: builtins.int
    API_KEY_FIELD_NUMBER: builtins.int
    api_url: builtins.str
    """The API URL for Opsgenie instance"""
    api_key: builtins.str
    """The API Key as provided by Opsgenie for configured Grafana integration."""
    def __init__(
        self,
        *,
        api_url: builtins.str = ...,
        api_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key", "api_url", b"api_url"]) -> None: ...

global___KubeOpsgenieNotificationChannelSettings = KubeOpsgenieNotificationChannelSettings



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SecretKeyRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KUBERNETES_SECRET_KEY_REF_FIELD_NUMBER: builtins.int
    @property
    def kubernetes_secret_key_ref(self) -> global___KubernetesSecretKeyRef: ...
    def __init__(
        self,
        *,
        kubernetes_secret_key_ref: global___KubernetesSecretKeyRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kubernetes_secret_key_ref", b"kubernetes_secret_key_ref", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kubernetes_secret_key_ref", b"kubernetes_secret_key_ref", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["kubernetes_secret_key_ref"] | None: ...

global___SecretKeyRef = SecretKeyRef

class KubernetesSecretKeyRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    name: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "name", b"name"]) -> None: ...

global___KubernetesSecretKeyRef = KubernetesSecretKeyRef



import contextlib

from dependency_injector.wiring import Provide, inject
from qwak.inner.runtime_di.containers import QwakRuntimeContainer


@inject
@contextlib.contextmanager
def qwak_timer(
    name, create_timer_function=Provide[QwakRuntimeContainer.timer_function_creator]
):
    """
    The Qwak timer is a utility for measuring the runtime of ML models, specifically for visibility and latency evaluation.
    It provides a convenient way to measure the time it takes for models to perform predictions
    and to provide a breakdown of the different parts in the production process
    Args:
        name (str): The Qwak timer name. Users may define multiple impl with different names
    """
    return create_timer_function(name)



from collections import defaultdict
from typing import Dict, List

from _qwak_proto.qwak.file_versioning.file_versioning_pb2 import FileTagSpec
from _qwak_proto.qwak.file_versioning.file_versioning_service_pb2 import (
    GetModelFileTagsRequest,
    GetModelFileTagsResponse,
    RegisterFileTagRequest,
    RegisterFileTagResponse,
)
from _qwak_proto.qwak.file_versioning.file_versioning_service_pb2_grpc import (
    FileVersioningManagementServiceServicer,
)
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error


class FileVersioningServiceMock(FileVersioningManagementServiceServicer):
    def __init__(self):
        super(FileVersioningServiceMock, self).__init__()
        self.tags: Dict[str : List[FileTagSpec]] = defaultdict(list)

    def RegisterFileTag(
        self, request: RegisterFileTagRequest, context
    ) -> RegisterFileTagResponse:
        try:
            self.tags[request.file_tag_spec.build_id].append(request.file_tag_spec)
            return RegisterFileTagResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def GetModelFileTags(
        self, request: GetModelFileTagsRequest, context
    ) -> GetModelFileTagsResponse:
        try:
            file_tags_list = []

            if not request.build_id:
                for all_file_tags in self.tags.values():
                    for file_tag in all_file_tags:
                        file_tags_list.append(file_tag)
            else:
                for file_tag_by_build_id in self.tags[request.build_id]:
                    if file_tag_by_build_id.model_id == request.model_id:
                        file_tags_list.append(file_tag_by_build_id)

            if request.filter:
                file_tags_list_filtered = list(file_tags_list)
                filter_type: str = request.filter.WhichOneof("filter")

                if filter_type == "tag_contains":
                    for file_tag in file_tags_list:
                        if request.filter.tag_contains not in file_tag.tag:
                            file_tags_list_filtered.remove(file_tag)

                if filter_type == "tag_prefix":
                    for file_tag in file_tags_list:
                        if not file_tag.tag.startswith(request.filter.tag_prefix):
                            file_tags_list_filtered.remove(file_tag)

                file_tags_list = file_tags_list_filtered

            return GetModelFileTagsResponse(file_tags=file_tags_list)
        except Exception as e:
            raise_internal_grpc_error(context, e)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/deployment/alert_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.deployment import alert_pb2 as qwak_dot_deployment_dot_alert__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#qwak/deployment/alert_service.proto\x12\x1aqwak.deployment.management\x1a\x1bqwak/deployment/alert.proto\"`\n\x1dGetAlertsConfigurationRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x16\n\x0e\x65nvironment_id\x18\x03 \x01(\t\"W\n\x1eGetAlertsConfigurationResponse\x12\x35\n\x06\x61lerts\x18\x01 \x03(\x0b\x32%.qwak.deployment.management.AlertRule\"\xad\x01\n\x1f\x41pplyAlertsConfigurationRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x35\n\x06\x61lerts\x18\x03 \x03(\x0b\x32%.qwak.deployment.management.AlertRule\x12\x12\n\nmodel_uuid\x18\x04 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\"\"\n ApplyAlertsConfigurationResponse\"<\n\"GetNotificationChannelsListRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"y\n#GetNotificationChannelsListResponse\x12R\n\x15notification_channels\x18\x01 \x03(\x0b\x32\x33.qwak.deployment.management.NotificationChannelSpec\"\x88\x01\n\x1f\x41pplyNotificationChannelRequest\x12M\n\x14notification_channel\x18\x01 \x01(\x0b\x32/.qwak.deployment.management.NotificationChannel\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"\"\n ApplyNotificationChannelResponse\"[\n DeleteNotificationChannelRequest\x12\x1f\n\x17notification_channel_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"#\n!DeleteNotificationChannelResponse\"B\n(GetNotificationChannelDetailsListRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"{\n)GetNotificationChannelDetailsListResponse\x12N\n\x15notification_channels\x18\x01 \x03(\x0b\x32/.qwak.deployment.management.NotificationChannel2\xc9\x07\n\x16\x41lertManagementService\x12\x8f\x01\n\x16GetAlertsConfiguration\x12\x39.qwak.deployment.management.GetAlertsConfigurationRequest\x1a:.qwak.deployment.management.GetAlertsConfigurationResponse\x12\x95\x01\n\x18\x41pplyAlertsConfiguration\x12;.qwak.deployment.management.ApplyAlertsConfigurationRequest\x1a<.qwak.deployment.management.ApplyAlertsConfigurationResponse\x12\x9e\x01\n\x1bGetNotificationChannelsList\x12>.qwak.deployment.management.GetNotificationChannelsListRequest\x1a?.qwak.deployment.management.GetNotificationChannelsListResponse\x12\x95\x01\n\x18\x41pplyNotificationChannel\x12;.qwak.deployment.management.ApplyNotificationChannelRequest\x1a<.qwak.deployment.management.ApplyNotificationChannelResponse\x12\x98\x01\n\x19\x44\x65leteNotificationChannel\x12<.qwak.deployment.management.DeleteNotificationChannelRequest\x1a=.qwak.deployment.management.DeleteNotificationChannelResponse\x12\xb0\x01\n!GetNotificationChannelDetailsList\x12\x44.qwak.deployment.management.GetNotificationChannelDetailsListRequest\x1a\x45.qwak.deployment.management.GetNotificationChannelDetailsListResponseB)\n%com.qwak.ai.management.deployment.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.deployment.alert_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001'
  _GETALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._options = None
  _GETALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _APPLYALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._options = None
  _APPLYALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _globals['_GETALERTSCONFIGURATIONREQUEST']._serialized_start=96
  _globals['_GETALERTSCONFIGURATIONREQUEST']._serialized_end=192
  _globals['_GETALERTSCONFIGURATIONRESPONSE']._serialized_start=194
  _globals['_GETALERTSCONFIGURATIONRESPONSE']._serialized_end=281
  _globals['_APPLYALERTSCONFIGURATIONREQUEST']._serialized_start=284
  _globals['_APPLYALERTSCONFIGURATIONREQUEST']._serialized_end=457
  _globals['_APPLYALERTSCONFIGURATIONRESPONSE']._serialized_start=459
  _globals['_APPLYALERTSCONFIGURATIONRESPONSE']._serialized_end=493
  _globals['_GETNOTIFICATIONCHANNELSLISTREQUEST']._serialized_start=495
  _globals['_GETNOTIFICATIONCHANNELSLISTREQUEST']._serialized_end=555
  _globals['_GETNOTIFICATIONCHANNELSLISTRESPONSE']._serialized_start=557
  _globals['_GETNOTIFICATIONCHANNELSLISTRESPONSE']._serialized_end=678
  _globals['_APPLYNOTIFICATIONCHANNELREQUEST']._serialized_start=681
  _globals['_APPLYNOTIFICATIONCHANNELREQUEST']._serialized_end=817
  _globals['_APPLYNOTIFICATIONCHANNELRESPONSE']._serialized_start=819
  _globals['_APPLYNOTIFICATIONCHANNELRESPONSE']._serialized_end=853
  _globals['_DELETENOTIFICATIONCHANNELREQUEST']._serialized_start=855
  _globals['_DELETENOTIFICATIONCHANNELREQUEST']._serialized_end=946
  _globals['_DELETENOTIFICATIONCHANNELRESPONSE']._serialized_start=948
  _globals['_DELETENOTIFICATIONCHANNELRESPONSE']._serialized_end=983
  _globals['_GETNOTIFICATIONCHANNELDETAILSLISTREQUEST']._serialized_start=985
  _globals['_GETNOTIFICATIONCHANNELDETAILSLISTREQUEST']._serialized_end=1051
  _globals['_GETNOTIFICATIONCHANNELDETAILSLISTRESPONSE']._serialized_start=1053
  _globals['_GETNOTIFICATIONCHANNELDETAILSLISTRESPONSE']._serialized_end=1176
  _globals['_ALERTMANAGEMENTSERVICE']._serialized_start=1179
  _globals['_ALERTMANAGEMENTSERVICE']._serialized_end=2148
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/builds/builds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.deployment import deployment_pb2 as qwak_dot_deployment_dot_deployment__pb2
from _qwak_proto.qwak.builds import build_pb2 as qwak_dot_builds_dot_build__pb2
from _qwak_proto.qwak.fitness_service import status_pb2 as qwak_dot_fitness__service_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18qwak/builds/builds.proto\x12\x16qwak.builds.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a qwak/deployment/deployment.proto\x1a\x17qwak/builds/build.proto\x1a!qwak/fitness_service/status.proto\"\xf4\x05\n\x05\x42uild\x12\x35\n\nbuild_spec\x18\x01 \x01(\x0b\x32!.qwak.builds.management.BuildSpec\x12\x39\n\x0c\x62uild_status\x18\x02 \x01(\x0e\x32#.qwak.builds.management.BuildStatus\x12\x39\n\x0cmodel_schema\x18\x03 \x01(\x0b\x32#.qwak.builds.management.ModelSchema\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12\x34\n\x10last_modified_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x07 \x01(\t\x12V\n\x17\x64\x65ployment_build_status\x18\x08 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatusB\x02\x18\x01\x12V\n\x14hosting_service_type\x18\t \x01(\x0e\x32\x38.qwak.deployment.management.DeploymentHostingServiceType\x12,\n\x08\x65nd_date\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\x16\x61vailable_environments\x18\x0b \x03(\t\x12\x1d\n\x15\x64\x65ployed_environments\x18\x0c \x03(\t\x12\x32\n\tpodStatus\x18\r \x01(\x0b\x32\x1f.qwak.fitness.service.PodStatus\x12\x16\n\x0eimage_name_tag\x18\x0e \x01(\t\x12\x41\n\x0f\x62uild_initiator\x18\x0f \x01(\x0b\x32(.qwak.builds.orchestrator.BuildInitiator\"\x86\x03\n\tBuildSpec\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x11\n\tcommit_id\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x13\n\x0b\x62ranch_name\x18\x04 \x01(\t\x12\x11\n\tbranch_id\x18\x08 \x01(\t\x12\x0c\n\x04tags\x18\x05 \x03(\t\x12T\n\x1a\x65xperiment_tracking_values\x18\x06 \x01(\x0b\x32\x30.qwak.builds.management.ExperimentTrackingValues\x12G\n\x13\x62uild_configuration\x18\x07 \x01(\x0b\x32*.qwak.builds.management.BuildConfiguration\x12\x17\n\x0f\x62uild_code_path\x18\t \x01(\t\x12\x13\n\x0b\x62uild_steps\x18\n \x03(\t\x12\x16\n\x0e\x65nvironment_id\x18\x0b \x01(\t\x12\x12\n\nmodel_uuid\x18\x0c \x01(\t\x12\x13\n\x0bsdk_version\x18\r \x01(\t\"\xee\x01\n\x0bModelSchema\x12\x30\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x31\n\x08\x66\x65\x61tures\x18\x02 \x03(\x0b\x32\x1f.qwak.builds.management.Feature\x12\x37\n\x0bpredictions\x18\x03 \x03(\x0b\x32\".qwak.builds.management.Prediction\x12\x41\n\x10inference_output\x18\x04 \x03(\x0b\x32\'.qwak.builds.management.InferenceOutput\"G\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"\xd0\x04\n\x07\x46\x65\x61ture\x12=\n\rbatch_feature\x18\x01 \x01(\x0b\x32$.qwak.builds.management.BatchFeatureH\x00\x12\x43\n\x10\x65xplicit_feature\x18\x02 \x01(\x0b\x32\'.qwak.builds.management.ExplicitFeatureH\x00\x12\x45\n\x12on_the_fly_feature\x18\x03 \x01(\x0b\x32\'.qwak.builds.management.OnTheFlyFeatureH\x00\x12\x45\n\x11streaming_feature\x18\x04 \x01(\x0b\x32(.qwak.builds.management.StreamingFeatureH\x00\x12=\n\rrequest_input\x18\x05 \x01(\x0b\x32$.qwak.builds.management.RequestInputH\x00\x12\\\n\x1dstreaming_aggregation_feature\x18\x06 \x01(\x0b\x32\x33.qwak.builds.management.StreamingAggregationFeatureH\x00\x12\x42\n\x10\x62\x61tch_feature_v1\x18\x07 \x01(\x0b\x32&.qwak.builds.management.BatchFeatureV1H\x00\x12J\n\x14streaming_feature_v1\x18\x08 \x01(\x0b\x32*.qwak.builds.management.StreamingFeatureV1H\x00\x42\x06\n\x04type\"\x8f\x01\n\x0fOnTheFlyFeature\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\x12>\n\x0fsource_features\x18\x03 \x03(\x0b\x32%.qwak.builds.management.SourceFeature\"N\n\x0e\x42\x61tchFeatureV1\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x12StreamingFeatureV1\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"L\n\x0c\x42\x61tchFeature\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"P\n\x10StreamingFeature\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"[\n\x1bStreamingAggregationFeature\x12.\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x1e.qwak.builds.management.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"P\n\x0f\x45xplicitFeature\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"M\n\x0cRequestInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"\x9b\x01\n\rSourceFeature\x12\x43\n\x10\x65xplicit_feature\x18\x01 \x01(\x0b\x32\'.qwak.builds.management.ExplicitFeatureH\x00\x12=\n\rrequest_input\x18\x02 \x01(\x0b\x32$.qwak.builds.management.RequestInputH\x00\x42\x06\n\x04type\"K\n\nPrediction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"P\n\x0fInferenceOutput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0b\x32!.qwak.builds.management.ValueType\"\xa6\x01\n\tValueType\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.qwak.builds.management.ValueType.Types\"b\n\x05Types\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05\x42YTES\x10\x01\x12\n\n\x06STRING\x10\x02\x12\t\n\x05INT32\x10\x03\x12\t\n\x05INT64\x10\x04\x12\n\n\x06\x44OUBLE\x10\x05\x12\t\n\x05\x46LOAT\x10\x06\x12\x08\n\x04\x42OOL\x10\x07\"j\n\x11ParameterCategory\"U\n\x08\x43\x61tegory\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06\x45NTITY\x10\x01\x12\x0b\n\x07\x46\x45\x41TURE\x10\x02\x12\x0e\n\nPREDICTION\x10\x03\x12\x13\n\x0fINFERENCEOUTPUT\x10\x04\"i\n\x1aRegisterModelSchemaRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x39\n\x0cmodel_schema\x18\x02 \x01(\x0b\x32#.qwak.builds.management.ModelSchema\"\x91\x01\n\'RegisterExperimentTrackingValuesRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12T\n\x1a\x65xperiment_tracking_values\x18\x02 \x01(\x0b\x32\x30.qwak.builds.management.ExperimentTrackingValues\"*\n(RegisterExperimentTrackingValuesResponse\"z\n\x18\x45xperimentTrackingValues\x12/\n\x07metrics\x18\x01 \x03(\x0b\x32\x1e.qwak.builds.management.Metric\x12-\n\x06params\x18\x02 \x03(\x0b\x32\x1d.qwak.builds.management.Param\"\xd1\x02\n\x12\x42uildConfiguration\x12\x46\n\x10\x62uild_properties\x18\x01 \x01(\x0b\x32,.qwak.builds.management.BuildPropertiesProto\x12;\n\tbuild_env\x18\x02 \x01(\x0b\x32(.qwak.builds.management.BuildEnvironment\x12;\n\tpre_build\x18\x03 \x01(\x0b\x32(.qwak.builds.management.BuildEnvironment\x12<\n\npost_build\x18\x04 \x01(\x0b\x32(.qwak.builds.management.BuildEnvironment\x12*\n\x04step\x18\x05 \x01(\x0b\x32\x1c.qwak.builds.management.Step\x12\x0f\n\x07verbose\x18\x06 \x01(\x05\"_\n\x04Step\x12\r\n\x05tests\x18\x01 \x01(\x08\x12\x1f\n\x17validate_build_artifact\x18\x02 \x01(\x08\x12\'\n\x1fvalidate_build_artifact_timeout\x18\x03 \x01(\x05\"\xc4\x01\n\x14\x42uildPropertiesProto\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x38\n\tmodel_uri\x18\x02 \x01(\x0b\x32%.qwak.builds.management.BuildModelUri\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x10\n\x08\x62uild_id\x18\x04 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x05 \x01(\t\x12\x18\n\x10\x65nvironment_name\x18\x06 \x01(\t\x12\x16\n\x0egpu_compatible\x18\x07 \x01(\x08\"g\n\rBuildModelUri\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x12\n\ngit_branch\x18\x02 \x01(\t\x12\x10\n\x08main_dir\x18\x03 \x01(\t\x12#\n\x1b\x64\x65pendency_required_folders\x18\x04 \x03(\t\"\xe8\x01\n\x10\x42uildEnvironment\x12\x33\n\x06\x64ocker\x18\x01 \x01(\x0b\x32#.qwak.builds.management.DockerBuild\x12\x31\n\x05local\x18\x02 \x01(\x0b\x32\".qwak.builds.management.LocalBuild\x12\x37\n\npython_env\x18\x03 \x01(\x0b\x32#.qwak.builds.management.PythonBuild\x12\x33\n\x06remote\x18\x04 \x01(\x0b\x32#.qwak.builds.management.RemoteBuild\"\x8a\x02\n\x0b\x44ockerBuild\x12\x12\n\nbase_image\x18\x01 \x01(\t\x12\x46\n\nbuild_args\x18\x02 \x03(\x0b\x32\x32.qwak.builds.management.DockerBuild.BuildArgsEntry\x12\x10\n\x08\x65nv_vars\x18\x03 \x03(\t\x12\x10\n\x08no_cache\x18\x04 \x01(\x08\x12\x0e\n\x06params\x18\x05 \x03(\t\x12\x1c\n\x14\x61ssumed_iam_role_arn\x18\x06 \x01(\t\x12\r\n\x05\x63\x61\x63he\x18\x07 \x01(\x08\x12\x0c\n\x04push\x18\x08 \x01(\x08\x1a\x30\n\x0e\x42uildArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\nLocalBuild\x12\x13\n\x0b\x61ws_profile\x18\x01 \x01(\t\x12\x0f\n\x07no_push\x18\x02 \x01(\x08\"\x9b\x02\n\x0bPythonBuild\x12 \n\x18qwak_sdk_extra_index_url\x18\x01 \x01(\t\x12\x43\n\nvirtualenv\x18\x02 \x01(\x0b\x32/.qwak.builds.management.VirtualEnvironmentBuild\x12\x31\n\x05\x63onda\x18\x03 \x01(\x0b\x32\".qwak.builds.management.CondaBuild\x12\x33\n\x06poetry\x18\x04 \x01(\x0b\x32#.qwak.builds.management.PoetryBuild\x12\x1c\n\x14\x64\x65pendency_file_path\x18\x05 \x01(\t\x12\x1f\n\x17use_deprecated_resolver\x18\x06 \x01(\x08\" \n\nCondaBuild\x12\x12\n\nconda_file\x18\x01 \x01(\t\"8\n\x0bPoetryBuild\x12\x16\n\x0epython_version\x18\x01 \x01(\t\x12\x11\n\tlock_file\x18\x02 \x01(\t\"K\n\x17VirtualEnvironmentBuild\x12\x16\n\x0epython_version\x18\x01 \x01(\t\x12\x18\n\x10requirements_txt\x18\x02 \x01(\t\"a\n\x0bRemoteBuild\x12\x11\n\tis_remote\x18\x01 \x01(\x08\x12?\n\tresources\x18\x02 \x01(\x0b\x32,.qwak.builds.management.RemoteBuildResources\"\x8f\x01\n\x14RemoteBuildResources\x12\x0c\n\x04\x63pus\x18\x01 \x01(\x02\x12\x0e\n\x06memory\x18\x02 \x01(\t\x12\x33\n\x08gpu_type\x18\x03 \x01(\x0e\x32!.qwak.builds.orchestrator.GpuType\x12\x12\n\ngpu_amount\x18\x04 \x01(\x05\x12\x10\n\x08instance\x18\x05 \x01(\t\"$\n\x06Metric\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\"#\n\x05Param\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t*\xe8\x01\n\x0b\x42uildStatus\x12\x0b\n\x07INVALID\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\x0e\n\nSUCCESSFUL\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x1d\n\x19REMOTE_BUILD_INITIALIZING\x10\x04\x12\x1a\n\x16REMOTE_BUILD_CANCELLED\x10\x05\x12\x1a\n\x16REMOTE_BUILD_TIMED_OUT\x10\x06\x12\x18\n\x14REMOTE_BUILD_UNKNOWN\x10\x07\x12\x18\n\x14SYNCING_ENVIRONMENTS\x10\x08\x12\x14\n\x10\x46INISHED_SYNCING\x10\tB%\n!com.qwak.ai.management.builds.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.builds.builds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.qwak.ai.management.builds.apiP\001'
  _BUILD.fields_by_name['deployment_build_status']._options = None
  _BUILD.fields_by_name['deployment_build_status']._serialized_options = b'\030\001'
  _DOCKERBUILD_BUILDARGSENTRY._options = None
  _DOCKERBUILD_BUILDARGSENTRY._serialized_options = b'8\001'
  _globals['_BUILDSTATUS']._serialized_start=6054
  _globals['_BUILDSTATUS']._serialized_end=6286
  _globals['_BUILD']._serialized_start=180
  _globals['_BUILD']._serialized_end=936
  _globals['_BUILDSPEC']._serialized_start=939
  _globals['_BUILDSPEC']._serialized_end=1329
  _globals['_MODELSCHEMA']._serialized_start=1332
  _globals['_MODELSCHEMA']._serialized_end=1570
  _globals['_ENTITY']._serialized_start=1572
  _globals['_ENTITY']._serialized_end=1643
  _globals['_FEATURE']._serialized_start=1646
  _globals['_FEATURE']._serialized_end=2238
  _globals['_ONTHEFLYFEATURE']._serialized_start=2241
  _globals['_ONTHEFLYFEATURE']._serialized_end=2384
  _globals['_BATCHFEATUREV1']._serialized_start=2386
  _globals['_BATCHFEATUREV1']._serialized_end=2464
  _globals['_STREAMINGFEATUREV1']._serialized_start=2466
  _globals['_STREAMINGFEATUREV1']._serialized_end=2548
  _globals['_BATCHFEATURE']._serialized_start=2550
  _globals['_BATCHFEATURE']._serialized_end=2626
  _globals['_STREAMINGFEATURE']._serialized_start=2628
  _globals['_STREAMINGFEATURE']._serialized_end=2708
  _globals['_STREAMINGAGGREGATIONFEATURE']._serialized_start=2710
  _globals['_STREAMINGAGGREGATIONFEATURE']._serialized_end=2801
  _globals['_EXPLICITFEATURE']._serialized_start=2803
  _globals['_EXPLICITFEATURE']._serialized_end=2883
  _globals['_REQUESTINPUT']._serialized_start=2885
  _globals['_REQUESTINPUT']._serialized_end=2962
  _globals['_SOURCEFEATURE']._serialized_start=2965
  _globals['_SOURCEFEATURE']._serialized_end=3120
  _globals['_PREDICTION']._serialized_start=3122
  _globals['_PREDICTION']._serialized_end=3197
  _globals['_INFERENCEOUTPUT']._serialized_start=3199
  _globals['_INFERENCEOUTPUT']._serialized_end=3279
  _globals['_VALUETYPE']._serialized_start=3282
  _globals['_VALUETYPE']._serialized_end=3448
  _globals['_VALUETYPE_TYPES']._serialized_start=3350
  _globals['_VALUETYPE_TYPES']._serialized_end=3448
  _globals['_PARAMETERCATEGORY']._serialized_start=3450
  _globals['_PARAMETERCATEGORY']._serialized_end=3556
  _globals['_PARAMETERCATEGORY_CATEGORY']._serialized_start=3471
  _globals['_PARAMETERCATEGORY_CATEGORY']._serialized_end=3556
  _globals['_REGISTERMODELSCHEMAREQUEST']._serialized_start=3558
  _globals['_REGISTERMODELSCHEMAREQUEST']._serialized_end=3663
  _globals['_REGISTEREXPERIMENTTRACKINGVALUESREQUEST']._serialized_start=3666
  _globals['_REGISTEREXPERIMENTTRACKINGVALUESREQUEST']._serialized_end=3811
  _globals['_REGISTEREXPERIMENTTRACKINGVALUESRESPONSE']._serialized_start=3813
  _globals['_REGISTEREXPERIMENTTRACKINGVALUESRESPONSE']._serialized_end=3855
  _globals['_EXPERIMENTTRACKINGVALUES']._serialized_start=3857
  _globals['_EXPERIMENTTRACKINGVALUES']._serialized_end=3979
  _globals['_BUILDCONFIGURATION']._serialized_start=3982
  _globals['_BUILDCONFIGURATION']._serialized_end=4319
  _globals['_STEP']._serialized_start=4321
  _globals['_STEP']._serialized_end=4416
  _globals['_BUILDPROPERTIESPROTO']._serialized_start=4419
  _globals['_BUILDPROPERTIESPROTO']._serialized_end=4615
  _globals['_BUILDMODELURI']._serialized_start=4617
  _globals['_BUILDMODELURI']._serialized_end=4720
  _globals['_BUILDENVIRONMENT']._serialized_start=4723
  _globals['_BUILDENVIRONMENT']._serialized_end=4955
  _globals['_DOCKERBUILD']._serialized_start=4958
  _globals['_DOCKERBUILD']._serialized_end=5224
  _globals['_DOCKERBUILD_BUILDARGSENTRY']._serialized_start=5176
  _globals['_DOCKERBUILD_BUILDARGSENTRY']._serialized_end=5224
  _globals['_LOCALBUILD']._serialized_start=5226
  _globals['_LOCALBUILD']._serialized_end=5276
  _globals['_PYTHONBUILD']._serialized_start=5279
  _globals['_PYTHONBUILD']._serialized_end=5562
  _globals['_CONDABUILD']._serialized_start=5564
  _globals['_CONDABUILD']._serialized_end=5596
  _globals['_POETRYBUILD']._serialized_start=5598
  _globals['_POETRYBUILD']._serialized_end=5654
  _globals['_VIRTUALENVIRONMENTBUILD']._serialized_start=5656
  _globals['_VIRTUALENVIRONMENTBUILD']._serialized_end=5731
  _globals['_REMOTEBUILD']._serialized_start=5733
  _globals['_REMOTEBUILD']._serialized_end=5830
  _globals['_REMOTEBUILDRESOURCES']._serialized_start=5833
  _globals['_REMOTEBUILDRESOURCES']._serialized_end=5976
  _globals['_METRIC']._serialized_start=5978
  _globals['_METRIC']._serialized_end=6014
  _globals['_PARAM']._serialized_start=6016
  _globals['_PARAM']._serialized_end=6051
# @@protoc_insertion_point(module_scope)



from __future__ import annotations

from dataclasses import dataclass

from qwak.inner.build_logic.interface.context_interface import Context


@dataclass
class TriggerBuildContext(Context):
    pass



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ObjectStorageConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    S3_FIELD_NUMBER: builtins.int
    GS_FIELD_NUMBER: builtins.int
    AZURE_BLOB_STORAGE_FIELD_NUMBER: builtins.int
    @property
    def s3(self) -> global___S3Configuration: ...
    @property
    def gs(self) -> global___GSConfiguration: ...
    @property
    def azure_blob_storage(self) -> global___AzureBlobConfiguration: ...
    def __init__(
        self,
        *,
        s3: global___S3Configuration | None = ...,
        gs: global___GSConfiguration | None = ...,
        azure_blob_storage: global___AzureBlobConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_blob_storage", b"azure_blob_storage", "gs", b"gs", "s3", b"s3", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_blob_storage", b"azure_blob_storage", "gs", b"gs", "s3", b"s3", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["s3", "gs", "azure_blob_storage"] | None: ...

global___ObjectStorageConfiguration = ObjectStorageConfiguration

class S3Configuration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    """This proto does not contain auth configuration, as by default it gets is auth from the hosting configuration.
    This is an extensible behaviour if needed (e.g: running on OpenShift while using S3 as and Object Storage)
    """
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket"]) -> None: ...

global___S3Configuration = S3Configuration

class GSConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    """This proto does not contain auth configuration, as by default it gets is auth from the hosting configuration.
    This is an extensible behaviour if needed (e.g: running on OpenShift while using S3 as and Object Storage)
    """
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket"]) -> None: ...

global___GSConfiguration = GSConfiguration

class AzureBlobConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    STORAGE_CONTAINER_NAME_FIELD_NUMBER: builtins.int
    storage_account_name: builtins.str
    """The Azure Storage Account name"""
    storage_container_name: builtins.str
    """The "bucket" representative in Azure"""
    def __init__(
        self,
        *,
        storage_account_name: builtins.str = ...,
        storage_container_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["storage_account_name", b"storage_account_name", "storage_container_name", b"storage_container_name"]) -> None: ...

global___AzureBlobConfiguration = AzureBlobConfiguration



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/state/execution_state.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.execution.v1.state import spark_execution_state_pb2 as qwak_dot_execution_dot_v1_dot_state_dot_spark__execution__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-qwak/execution/v1/state/execution_state.proto\x12%qwak.feature.store.execution.v1.state\x1a\x33qwak/execution/v1/state/spark_execution_state.proto\"\xba\x01\n\x0e\x45xecutionState\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x15\n\rfeatureset_id\x18\x02 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x03 \x01(\t\x12U\n\x0fspark_app_state\x18\x04 \x01(\x0b\x32:.qwak.feature.store.execution.v1.state.SparkExecutionStateH\x00\x42\x0c\n\nexec_stateB`\n+com.qwak.ai.features.execution.api.v1.stateP\x01Z/qwak/execution_management/state;execution_stateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.state.execution_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.qwak.ai.features.execution.api.v1.stateP\001Z/qwak/execution_management/state;execution_state'
  _globals['_EXECUTIONSTATE']._serialized_start=142
  _globals['_EXECUTIONSTATE']._serialized_end=328
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.external.kafka_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ModelAnalyticsStorageConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KAFKA_FIELD_NUMBER: builtins.int
    @property
    def kafka(self) -> qwak.administration.runtime_configuration.v0.external.kafka_config_pb2.KafkaConfiguration: ...
    def __init__(
        self,
        *,
        kafka: qwak.administration.runtime_configuration.v0.external.kafka_config_pb2.KafkaConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kafka", b"kafka", "storage_type", b"storage_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kafka", b"kafka", "storage_type", b"storage_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["storage_type", b"storage_type"]) -> typing_extensions.Literal["kafka"] | None: ...

global___ModelAnalyticsStorageConfiguration = ModelAnalyticsStorageConfiguration



from typing import Union
from urllib.parse import ParseResult

from qwak.exceptions import QwakException


class QwakGrpcAddressException(QwakException):
    def __init__(self, details: str, grpc_address: Union[str, ParseResult]):
        self.message = f"Not a valid gRPC address: '{grpc_address}'. Details: {details}"



import warnings
from filelock import FileLock

from qwak.inner.di_configuration.session import Session
from abc import ABC, abstractmethod
from typing import Optional

warnings.filterwarnings(action="ignore", module=".*jose.*")

import configparser  # noqa E402
import json  # noqa E402

import requests  # noqa E402
from jose import jwt  # noqa E402
from qwak.exceptions import QwakLoginException  # noqa E402
from qwak.inner.const import QwakConstants  # noqa E402


class BaseAuthClient(ABC):
    @abstractmethod
    def get_token(self) -> Optional[str]:
        pass

    @abstractmethod
    def login(self) -> None:
        pass

    @abstractmethod
    def get_base_url(self) -> str:
        """
        Returns the base URL for the authentication service.
        """
        return ""


class Auth0ClientBase(BaseAuthClient):
    _TOKENS_FIELD = "TOKENS"

    def __init__(
        self,
        api_key=None,
        auth_file=QwakConstants.QWAK_AUTHORIZATION_FILE,
        audience=QwakConstants.TOKEN_AUDIENCE,
    ):
        self._auth_file = auth_file
        self._config = configparser.ConfigParser()
        self._environment = Session().get_environment()
        self.jwks = requests.get(QwakConstants.AUTH0_JWKS_URI, timeout=60).json()
        self.token = None
        self.audience = audience
        self.api_key = api_key

    def get_base_url(self) -> str:
        return QwakConstants.QWAK_APP_URL

    # Returns Non if token is expired
    def get_token(self):
        if self._environment != Session().get_environment():
            self.token = None
            self.api_key = None
            self._environment = Session().get_environment()
        try:
            if not self.token:
                self._config.read(self._auth_file)
                self.token = json.loads(
                    self._config.get(
                        section=self._environment, option=self._TOKENS_FIELD
                    )
                )

            # Test that token isn't expired
            self.get_claims()
            return self.token
        except configparser.NoSectionError:
            self.login()
            return self.token
        except jwt.ExpiredSignatureError:
            self.login()
            return self.token

    def login(self):
        from qwak.clients.administration import AuthenticationClient

        if not self.api_key:
            from qwak.inner.di_configuration import UserAccountConfiguration

            user_account = UserAccountConfiguration().get_user_config()
            self.api_key = user_account.api_key

        self.token = AuthenticationClient().authenticate(self.api_key).access_token

        from pathlib import Path

        Path(self._auth_file).parent.mkdir(parents=True, exist_ok=True)
        self._config.read(self._auth_file)

        lock_path = f"{self._auth_file}.lock"  # Create a lock file
        with FileLock(lock_path):  # Use file lock
            with open(self._auth_file, "w") as configfile:
                self._config[self._environment] = {
                    self._TOKENS_FIELD: json.dumps(self.token)
                }

                self._config.write(configfile)

    def get_claims(self):
        try:
            if not self.token:
                self.get_token()
            unverified_header = jwt.get_unverified_header(self.token)
            rsa_key = {}
            for key in self.jwks["keys"]:
                if key["kid"] == unverified_header["kid"]:
                    rsa_key = {
                        "kty": key["kty"],
                        "kid": key["kid"],
                        "use": key["use"],
                        "n": key["n"],
                        "e": key["e"],
                    }
            if rsa_key:
                payload = jwt.decode(
                    self.token,
                    rsa_key,
                    algorithms=QwakConstants.AUTH0_ALGORITHMS,
                    audience=self.audience,
                )
                claims = {}
                token_prefix = QwakConstants.TOKEN_AUDIENCE
                claims["exp"] = payload["exp"]
                for key in payload:
                    if key.startswith(token_prefix):
                        claims[key.split(token_prefix)[1]] = payload[key]
                return claims
            raise QwakLoginException()
        except jwt.ExpiredSignatureError as e:
            raise e
        except Exception:
            raise QwakLoginException()



import os
from pathlib import Path
from typing import Any, Dict, Optional

from qwak.exceptions import QwakException
from qwak.feature_store._common import packaging
from qwak.feature_store._common.source_code_spec import (
    JfrogArtifact,
    SourceCodeSpec,
    ZipArtifact,
)


class SourceCodeSpecFactory:
    @staticmethod
    def _upload_source_code_dir(
        main_entity_path: Path, url: str, extra_headers: Dict[str, Any]
    ):
        zip_location: Optional[Path] = None
        try:
            zip_location = packaging.zip_source_code_dir(base_path=main_entity_path)
            with open(zip_location, "rb") as zip_file:
                packaging.put_files_content(
                    url=url,
                    content=zip_file.read(),
                    content_type="application/octet-stream",
                    extra_headers=extra_headers,
                )
        except Exception as e:
            raise QwakException("Got an error while trying to upload file.") from e
        finally:
            if zip_location:
                os.remove(zip_location)

    @classmethod
    def get_zip_source_code_spec(
        cls,
        main_entity_path: Path,
        url: str,
        extra_headers: Optional[Dict[str, str]] = None,
    ) -> SourceCodeSpec:
        """
        Zips and upload the artifact,
        the main "entity" relative path is set as the main_entity_path
        """
        cls._upload_source_code_dir(
            main_entity_path=main_entity_path,
            url=url,
            extra_headers=extra_headers or {},
        )

        parent_base_path = (
            main_entity_path.parent if main_entity_path.is_file() else main_entity_path
        )

        if cls._is_artifactory_source_code(extra_headers):
            return cls._build_artifactory_source_code_spec(
                url=url,
                parent_base_path=parent_base_path,
                main_entity_path=main_entity_path,
            )
        else:
            return cls._build_qwak_source_code_spec(
                url=url,
                parent_base_path=parent_base_path,
                main_entity_path=main_entity_path,
            )

    @classmethod
    def _is_artifactory_source_code(
        cls, extra_headers: Optional[Dict[str, str]]
    ) -> bool:
        """
        Check if the source code is from Artifactory by checking the extra headers.
        """
        if not extra_headers:
            return False
        return True

    @classmethod
    def _build_artifactory_source_code_spec(
        cls, url: str, parent_base_path: Path, main_entity_path: Path
    ) -> SourceCodeSpec:
        return SourceCodeSpec(
            artifact=ZipArtifact(
                jfrog_artifact_path=JfrogArtifact(path=url),
                main_file=str(
                    Path(parent_base_path.name) / Path(main_entity_path.name)
                ),
            )
        )

    @classmethod
    def _build_qwak_source_code_spec(
        cls, url: str, parent_base_path: Path, main_entity_path: Path
    ) -> SourceCodeSpec:
        return SourceCodeSpec(
            artifact=ZipArtifact(
                qwak_artifact_path=url,
                main_file=str(
                    Path(parent_base_path.name) / Path(main_entity_path.name)
                ),
            )
        )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.model_group.model_group_repository_details_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetModelGroupSystemPullImageSecretRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_GROUP_SYSTEM_PULL_SECRET_IDENTIFIERS_FIELD_NUMBER: builtins.int
    @property
    def model_group_system_pull_secret_identifiers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModelGroupSystemPullSecretIdentifier]: ...
    def __init__(
        self,
        *,
        model_group_system_pull_secret_identifiers: collections.abc.Iterable[global___ModelGroupSystemPullSecretIdentifier] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_group_system_pull_secret_identifiers", b"model_group_system_pull_secret_identifiers"]) -> None: ...

global___GetModelGroupSystemPullImageSecretRequest = GetModelGroupSystemPullImageSecretRequest

class ModelGroupSystemPullSecretIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_GROUP_NAME_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    model_group_name: builtins.str
    account_id: builtins.str
    def __init__(
        self,
        *,
        model_group_name: builtins.str = ...,
        account_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_group_identifier", b"model_group_identifier", "model_group_name", b"model_group_name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "model_group_identifier", b"model_group_identifier", "model_group_name", b"model_group_name"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["model_group_identifier", b"model_group_identifier"]) -> typing_extensions.Literal["model_group_name"] | None: ...

global___ModelGroupSystemPullSecretIdentifier = ModelGroupSystemPullSecretIdentifier

class SystemPullSecretInfoNamesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_INFOS_FIELD_NUMBER: builtins.int
    @property
    def secret_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SystemPullSecretInfo]: ...
    def __init__(
        self,
        *,
        secret_infos: collections.abc.Iterable[global___SystemPullSecretInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret_infos", b"secret_infos"]) -> None: ...

global___SystemPullSecretInfoNamesResponse = SystemPullSecretInfoNamesResponse

class SystemPullSecretInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_GROUP_NAME_FIELD_NUMBER: builtins.int
    SECRET_PULL_IMAGE_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    model_group_name: builtins.str
    secret_pull_image: builtins.str
    account_id: builtins.str
    def __init__(
        self,
        *,
        model_group_name: builtins.str = ...,
        secret_pull_image: builtins.str = ...,
        account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "model_group_name", b"model_group_name", "secret_pull_image", b"secret_pull_image"]) -> None: ...

global___SystemPullSecretInfo = SystemPullSecretInfo

class CreateIfNotExistsModelGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_GROUP_NAME_FIELD_NUMBER: builtins.int
    JFROG_PROJECT_KEY_FIELD_NUMBER: builtins.int
    model_group_name: builtins.str
    """Model group name"""
    jfrog_project_key: builtins.str
    """Artifactory project key used for repository organization"""
    def __init__(
        self,
        *,
        model_group_name: builtins.str = ...,
        jfrog_project_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jfrog_project_key", b"jfrog_project_key", "model_group_name", b"model_group_name"]) -> None: ...

global___CreateIfNotExistsModelGroupRequest = CreateIfNotExistsModelGroupRequest

class ModelGroupBriefInfoResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_GROUP_ID_FIELD_NUMBER: builtins.int
    MODEL_GROUP_DESCRIPTION_FIELD_NUMBER: builtins.int
    MODEL_GROUP_CREATED_AT_FIELD_NUMBER: builtins.int
    REPOSITORY_DETAILS_FIELD_NUMBER: builtins.int
    model_group_id: builtins.str
    """Unique identifier for the model group"""
    model_group_description: builtins.str
    """Description of the model group"""
    @property
    def model_group_created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The model group creation timestamp"""
    @property
    def repository_details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.model_group.model_group_repository_details_pb2.RepositoryDetails]:
        """List of repository details associated with this model group"""
    def __init__(
        self,
        *,
        model_group_id: builtins.str = ...,
        model_group_description: builtins.str = ...,
        model_group_created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        repository_details: collections.abc.Iterable[qwak.model_group.model_group_repository_details_pb2.RepositoryDetails] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_group_created_at", b"model_group_created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_group_created_at", b"model_group_created_at", "model_group_description", b"model_group_description", "model_group_id", b"model_group_id", "repository_details", b"repository_details"]) -> None: ...

global___ModelGroupBriefInfoResponse = ModelGroupBriefInfoResponse

class CreateRepositoriesForModelGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_GROUP_UUID_FIELD_NUMBER: builtins.int
    REPOSITORY_DETAILS_FIELD_NUMBER: builtins.int
    model_group_uuid: builtins.str
    """the model group UUID for which to create repositories"""
    @property
    def repository_details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.model_group.model_group_repository_details_pb2.RemoteRepositoryDetails]:
        """List of remote repository details to create for the model group"""
    def __init__(
        self,
        *,
        model_group_uuid: builtins.str = ...,
        repository_details: collections.abc.Iterable[qwak.model_group.model_group_repository_details_pb2.RemoteRepositoryDetails] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_group_uuid", b"model_group_uuid", "repository_details", b"repository_details"]) -> None: ...

global___CreateRepositoriesForModelGroupRequest = CreateRepositoriesForModelGroupRequest

class CreateRepositoriesForModelGroupResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARTIFACTORY_REPOSITORY_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def artifactory_repository_details(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.model_group.model_group_repository_details_pb2.RepositoryDetails]:
        """List of repository details associated with this model group"""
    def __init__(
        self,
        *,
        artifactory_repository_details: collections.abc.Iterable[qwak.model_group.model_group_repository_details_pb2.RepositoryDetails] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifactory_repository_details", b"artifactory_repository_details"]) -> None: ...

global___CreateRepositoriesForModelGroupResponse = CreateRepositoriesForModelGroupResponse

class GetModelGroupInfoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_GROUP_NAME_FIELD_NUMBER: builtins.int
    JFROG_PROJECT_KEY_FIELD_NUMBER: builtins.int
    model_group_name: builtins.str
    """Model group name"""
    jfrog_project_key: builtins.str
    """Artifactory project key used for repository organization"""
    def __init__(
        self,
        *,
        model_group_name: builtins.str = ...,
        jfrog_project_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jfrog_project_key", b"jfrog_project_key", "model_group_name", b"model_group_name"]) -> None: ...

global___GetModelGroupInfoRequest = GetModelGroupInfoRequest
